
import React from 'react';
import SEO from '@/components/SEO';
import Header from '@/components/Header';
import HeroSection from '@/components/HeroSection';
import WhatWeDoSection from '@/components/WhatWeDoSection';
import SolutionsGrid from '@/components/SolutionsGrid';
import WhyCorsoftSection from '@/components/WhyCorsoftSection';
import FinalCtaSection from '@/components/FinalCtaSection';
import Footer from '@/components/Footer';

const Index = () => {
  const organizationSchema = {
    "@context": "https://schema.org",
    "@type": "Organization",
    "name": "Corshift",
    "alternateName": ["Corshift Consulting", "Corshift Product Consulting"],
    "description": "Corshift is a product consulting company that helps businesses transform their vision into impactful digital products. We specialize in MVP development, product strategy, UX design, and scaling digital products.",
    "url": "https://corshift.com",
    "logo": "https://corshift.com/lovable-uploads/634a786f-f75b-4992-a24b-0b3abe90a675.png",
    "image": "https://corshift.com/lovable-uploads/634a786f-f75b-4992-a24b-0b3abe90a675.png",
    "foundingDate": "2024",
    "founder": {
      "@type": "Person",
      "name": "Corshift Team"
    },
    "contactPoint": [
      {
        "@type": "ContactPoint",
        "email": "hello@corshift.com",
        "contactType": "customer service",
        "availableLanguage": "English"
      }
    ],
    "sameAs": [
      "https://linkedin.com/company/corshift"
    ],
    "address": {
      "@type": "PostalAddress",
      "addressCountry": "IN"
    },
    "serviceArea": {
      "@type": "Place",
      "name": "Global"
    },
    "hasOfferCatalog": {
      "@type": "OfferCatalog",
      "name": "Product Consulting Services",
      "itemListElement": [
        {
          "@type": "Offer",
          "itemOffered": {
            "@type": "Service",
            "name": "Strategic Launchpad",
            "description": "MVP validation, market alignment, and go-to-market strategy"
          }
        },
        {
          "@type": "Offer",
          "itemOffered": {
            "@type": "Service",
            "name": "Scaling Blueprint",
            "description": "Product audits, growth strategy, and user retention optimization"
          }
        },
        {
          "@type": "Offer",
          "itemOffered": {
            "@type": "Service",
            "name": "Product Command",
            "description": "Leadership coaching, roadmap alignment, and strategic decision-making"
          }
        },
        {
          "@type": "Offer",
          "itemOffered": {
            "@type": "Service",
            "name": "Insight-Driven Design",
            "description": "Data-backed research and user-centric design"
          }
        }
      ]
    }
  };

  const breadcrumbSchema = {
    "@context": "https://schema.org",
    "@type": "BreadcrumbList",
    "itemListElement": [
      {
        "@type": "ListItem",
        "position": 1,
        "name": "Home",
        "item": "https://corshift.com"
      }
    ]
  };

  const websiteSchema = {
    "@context": "https://schema.org",
    "@type": "WebSite",
    "name": "Corshift",
    "url": "https://corshift.com",
    "potentialAction": {
      "@type": "SearchAction",
      "target": "https://corshift.com/search?q={search_term_string}",
      "query-input": "required name=search_term_string"
    }
  };

  const combinedSchema = {
    "@context": "https://schema.org",
    "@graph": [organizationSchema, breadcrumbSchema, websiteSchema]
  };

  return (
    <div className="min-h-screen flex flex-col">
      <SEO 
        title="Corshift - Product Consulting for Real-World Impact"
        description="Corshift helps companies design smarter, research deeper, and launch with clarity. From first idea to scaling success, we strategize, design, and manage digital products for measurable outcomes."
        canonicalUrl="/"
        keywords="Corshift, product consulting, digital products, MVP development, product strategy, UX design, product management, startup consulting, scaling products, product research"
        schema={combinedSchema}
      />
      
      <Header />
      
      <main className="flex-grow">
        <HeroSection />
        <WhatWeDoSection />
        <SolutionsGrid />
        <WhyCorsoftSection />
        <FinalCtaSection />
      </main>
      
      <Footer />
    </div>
  );
};

export default Index;
